@@ -29,13 +29,12 @@
 #include <string.h>
 #include <panel-applet.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkbox.h>
-#include <libgnomeui/gnome-help.h>
-#include <libdbus-watch.h>
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
 
-#include "../src/gpm-common.h"
+#include "egg-debug.h"
+#include "egg-dbus-monitor.h"
+#include "gpm-common.h"
 
 #define GPM_TYPE_INHIBIT_APPLET		(gpm_inhibit_applet_get_type ())
 #define GPM_INHIBIT_APPLET(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GPM_TYPE_INHIBIT_APPLET, GpmInhibitApplet))
@@ -54,7 +53,7 @@ typedef struct{
 	/* connection to g-p-m */
 	DBusGProxy *proxy;
 	DBusGConnection *connection;
-	DbusWatch *watch;
+	EggDbusMonitor *monitor;
 	guint level;
 	/* a cache for panel size */
 	gint size;
@@ -105,7 +104,7 @@ gpm_applet_inhibit (GpmInhibitApplet *applet,
 	g_return_val_if_fail (cookie != NULL, FALSE);
 
 	if (applet->proxy == NULL) {
-		printf ("WARNING: not connected\n");
+		egg_warning ("not connected\n");
 		return FALSE;
 	}
 
@@ -136,7 +135,7 @@ gpm_applet_uninhibit (GpmInhibitApplet *applet,
 	gboolean ret;
 
 	if (applet->proxy == NULL) {
-		printf ("WARNING: not connected");
+		egg_warning ("not connected");
 		return FALSE;
 	}
 
@@ -164,7 +163,7 @@ gpm_applet_has_inhibit (GpmInhibitApplet *applet,
 	gboolean ret;
 	DBusGProxy *proxy;
 
-	proxy = dbus_proxy_get_proxy (applet->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (applet->gproxy);
 	if (proxy == NULL) {
 		g_warning ("not connected");
 		return FALSE;
@@ -436,7 +435,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 				     _(license[2]), "\n\n", _(license[3]), "\n", NULL);
 
 	about = (GtkAboutDialog*) gtk_about_dialog_new ();
-	gtk_about_dialog_set_name (about, GPM_INHIBIT_APPLET_NAME);
+	gtk_about_dialog_set_program_name (about, GPM_INHIBIT_APPLET_NAME);
 	gtk_about_dialog_set_version (about, VERSION);
 	gtk_about_dialog_set_copyright (about, _("Copyright \xc2\xa9 2006-2007 Richard Hughes"));
 	gtk_about_dialog_set_comments (about, GPM_INHIBIT_APPLET_DESC);
@@ -453,7 +452,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 	gtk_widget_show (GTK_WIDGET(about));
 
 	g_free (license_trans);
-	gdk_pixbuf_unref (logo);
+	g_object_unref (logo);
 }
 
 /**
@@ -464,24 +463,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
 static void
 gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-	GError *error = NULL;
-	GpmInhibitApplet *applet = GPM_INHIBIT_APPLET(data);
-	GnomeProgram *program = gnome_program_get ();
-
-	gnome_help_display_with_doc_id (program, "gnome-power-manager",
-					"gnome-power-manager.xml",
-					"applets-inhibit", &error);
-	if (error != NULL) {
-		GtkWidget *dialog =
-			gtk_message_dialog_new (GTK_WINDOW (GTK_WIDGET(applet)->parent),
-						GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_ERROR,
-						GTK_BUTTONS_CLOSE,
-						"%s", error->message);
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-		g_error_free (error);
-	}
+	gpm_help_display ("applets-inhibit");
 }
 
 /**
@@ -493,11 +475,11 @@ gpm_applet_destroy_cb (GtkObject *object)
 {
 	GpmInhibitApplet *applet = GPM_INHIBIT_APPLET(object);
 
-	if (applet->watch != NULL) {
-		g_object_unref (applet->watch);
+	if (applet->monitor != NULL) {
+		g_object_unref (applet->monitor);
 	}
 	if (applet->icon != NULL) {
-		gdk_pixbuf_unref (applet->icon);
+		g_object_unref (applet->icon);
 	}
 }
 
@@ -521,18 +503,18 @@ gpm_inhibit_applet_dbus_connect (GpmInhibitApplet *applet)
 	GError *error = NULL;
 
 	if (applet->connection == NULL) {
-		printf ("DEBUG: get connection\n");
+		egg_debug ("get connection\n");
 		g_clear_error (&error);
 		applet->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 		if (error != NULL) {
-			printf ("WARNING: Could not connect to DBUS daemon: %s", error->message);
+			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			applet->connection = NULL;
 			return FALSE;
 		}
 	}
 	if (applet->proxy == NULL) {
-		printf ("DEBUG: get proxy\n");
+		egg_debug ("get proxy\n");
 		g_clear_error (&error);
 		applet->proxy = dbus_g_proxy_new_for_name_owner (applet->connection,
 							 GPM_DBUS_SERVICE,
@@ -540,7 +522,7 @@ gpm_inhibit_applet_dbus_connect (GpmInhibitApplet *applet)
 							 GPM_DBUS_INTERFACE_INHIBIT,
 							 &error);
 		if (error != NULL) {
-			printf ("WARNING: Cannot connect, maybe the daemon is not running: %s\n", error->message);
+			egg_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
 			g_error_free (error);
 			applet->proxy = NULL;
 			return FALSE;
@@ -556,7 +538,7 @@ gboolean
 gpm_inhibit_applet_dbus_disconnect (GpmInhibitApplet *applet)
 {
 	if (applet->proxy != NULL) {
-		printf ("DEBUG: removing proxy\n");
+		egg_debug ("removing proxy\n");
 		g_object_unref (applet->proxy);
 		applet->proxy = NULL;
 		/* we have no inhibit, these are not persistant across reboots */
@@ -566,13 +548,13 @@ gpm_inhibit_applet_dbus_disconnect (GpmInhibitApplet *applet)
 }
 
 /**
- * watch_connection_cb:
+ * monitor_connection_cb:
  * @proxy: The dbus raw proxy
  * @status: The status of the service, where TRUE is connected
  * @screensaver: This class instance
  **/
 static void
-watch_connection_cb (DbusWatch           *watch,
+monitor_connection_cb (EggDbusMonitor           *monitor,
 		     gboolean	          status,
 		     GpmInhibitApplet *applet)
 {
@@ -596,6 +578,8 @@ watch_connection_cb (DbusWatch           *watch,
 static void
 gpm_inhibit_applet_init (GpmInhibitApplet *applet)
 {
+	DBusGConnection *connection;
+
 	/* initialize fields */
 	applet->size = 0;
 	applet->icon = NULL;
@@ -607,10 +591,11 @@ gpm_inhibit_applet_init (GpmInhibitApplet *applet)
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
-	applet->watch = dbus_watch_new ();
-	g_signal_connect (applet->watch, "connection-changed",
-			  G_CALLBACK (watch_connection_cb), applet);
-	dbus_watch_assign (applet->watch, DBUS_WATCH_SESSION, GPM_DBUS_SERVICE);
+	applet->monitor = egg_dbus_monitor_new ();
+	g_signal_connect (applet->monitor, "connection-changed",
+			  G_CALLBACK (monitor_connection_cb), applet);
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	egg_dbus_monitor_assign (applet->monitor, connection, GPM_DBUS_SERVICE);
 	gpm_inhibit_applet_dbus_connect (applet);
 
 	/* prepare */
