@@ -23,7 +23,8 @@
 #define __GPM_GRAPH_WIDGET_H__
 
 #include <gtk/gtk.h>
-#include "gpm-array.h"
+#include "egg-obj-list.h"
+#include "gpm-point-obj.h"
 
 G_BEGIN_DECLS
 
@@ -40,40 +41,31 @@ typedef struct GpmGraphWidget		GpmGraphWidget;
 typedef struct GpmGraphWidgetClass	GpmGraphWidgetClass;
 typedef struct GpmGraphWidgetPrivate	GpmGraphWidgetPrivate;
 
-typedef enum {
-	GPM_GRAPH_WIDGET_SHAPE_CIRCLE,
-	GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-	GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
-	GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-	GPM_GRAPH_WIDGET_SHAPE_LAST
-} GpmGraphWidgetShape;
-
 typedef enum {
 	GPM_GRAPH_WIDGET_TYPE_INVALID,
 	GPM_GRAPH_WIDGET_TYPE_PERCENTAGE,
+	GPM_GRAPH_WIDGET_TYPE_FACTOR,
 	GPM_GRAPH_WIDGET_TYPE_TIME,
 	GPM_GRAPH_WIDGET_TYPE_POWER,
 	GPM_GRAPH_WIDGET_TYPE_VOLTAGE,
-	GPM_GRAPH_WIDGET_TYPE_LAST
-} GpmGraphWidgetAxisType;
+	GPM_GRAPH_WIDGET_TYPE_UNKNOWN
+} GpmGraphWidgetType;
 
-/* the different kinds of dots in the key */
-typedef struct {
-	guint			 id;
-	guint32			 colour;
-	GpmGraphWidgetShape	 shape;
-	gchar			*desc;
-} GpmGraphWidgetKeyItem;
+typedef enum {
+	GPM_GRAPH_WIDGET_PLOT_LINE,
+	GPM_GRAPH_WIDGET_PLOT_POINTS,
+	GPM_GRAPH_WIDGET_PLOT_BOTH
+} GpmGraphWidgetPlot;
 
 /* the different kinds of lines in the key */
 typedef struct {
-	guint32			 colour;
+	guint32			 color;
 	gchar			*desc;
 } GpmGraphWidgetKeyData;
 
 struct GpmGraphWidget
 {
-	GtkDrawingArea	 parent;
+	GtkDrawingArea		 parent;
 	GpmGraphWidgetPrivate	*priv;
 };
 
@@ -85,32 +77,19 @@ struct GpmGraphWidgetClass
 GType		 gpm_graph_widget_get_type		(void);
 GtkWidget	*gpm_graph_widget_new			(void);
 
-void		 gpm_graph_widget_enable_legend		(GpmGraphWidget	*graph,
-							 gboolean	 enable);
-void		 gpm_graph_widget_enable_events		(GpmGraphWidget	*graph,
-							 gboolean	 enable);
-gboolean	 gpm_graph_widget_data_add		(GpmGraphWidget	*graph,
-							 GpmArray	*array);
-void		 gpm_graph_widget_data_clear		(GpmGraphWidget	*graph);
-void		 gpm_graph_widget_events_add		(GpmGraphWidget	*graph,
-							 GpmArray	*array);
-void		 gpm_graph_widget_events_clear		(GpmGraphWidget	*graph);
-void		 gpm_graph_widget_set_axis_type_x	(GpmGraphWidget	*graph,
-							 GpmGraphWidgetAxisType axis);
-void		 gpm_graph_widget_set_axis_type_y	(GpmGraphWidget	*graph,
-							 GpmGraphWidgetAxisType axis);
-gboolean	 gpm_graph_widget_key_data_clear	(GpmGraphWidget	*graph);
-gboolean	 gpm_graph_widget_key_data_add		(GpmGraphWidget	*graph,
-							 guint		 colour,
-							 const gchar	*desc);
-gboolean	 gpm_graph_widget_key_event_clear	(GpmGraphWidget	*graph);
-gboolean	 gpm_graph_widget_key_event_add		(GpmGraphWidget	*graph,
-							 guint		 id,
-							 guint32	 colour,
-							 GpmGraphWidgetShape shape,
-							 const gchar	*name);
-
-GpmGraphWidgetAxisType	 gpm_graph_widget_string_to_axis_type (const gchar	*type);
+void		 gpm_graph_widget_enable_legend		(GpmGraphWidget		*graph,
+							 gboolean		 enable);
+gboolean	 gpm_graph_widget_data_clear		(GpmGraphWidget		*graph);
+gboolean	 gpm_graph_widget_data_assign		(GpmGraphWidget		*graph,
+							 GpmGraphWidgetPlot	 plot,
+							 EggObjList		*array);
+void		 gpm_graph_widget_set_type_x		(GpmGraphWidget		*graph,
+							 GpmGraphWidgetType	 axis);
+void		 gpm_graph_widget_set_type_y		(GpmGraphWidget		*graph,
+							 GpmGraphWidgetType	 axis);
+gboolean	 gpm_graph_widget_key_data_add		(GpmGraphWidget		*graph,
+							 guint32		 color,
+							 const gchar		*desc);
 
 G_END_DECLS
 
