@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2008 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -33,14 +33,6 @@ G_BEGIN_DECLS
 #define GPM_IS_SCREENSAVER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GPM_TYPE_SCREENSAVER))
 #define GPM_SCREENSAVER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GPM_TYPE_SCREENSAVER, GpmScreensaverClass))
 
-#define GS_LISTENER_SERVICE	"org.gnome.ScreenSaver"
-#define GS_LISTENER_PATH	"/org/gnome/ScreenSaver"
-#define GS_LISTENER_INTERFACE	"org.gnome.ScreenSaver"
-
-#define GS_PREF_DIR		"/apps/gnome-screensaver"
-#define GS_PREF_LOCK_ENABLED	GS_PREF_DIR "/lock_enabled"
-#define GS_PREF_IDLE_DELAY	GS_PREF_DIR "/idle_delay"
-
 typedef struct GpmScreensaverPrivate GpmScreensaverPrivate;
 
 typedef struct
@@ -58,29 +50,21 @@ typedef struct
 					    		 gboolean	 connected);
 	void		(* auth_request)		(GpmScreensaver	*screensaver,
 					    		 gboolean	 auth);
-	void		(* session_idle_changed)	(GpmScreensaver	*screensaver,
-					    		 gboolean	 is_idle);
-	void		(* powersave_idle_changed)	(GpmScreensaver	*screensaver,
-					    		 gboolean	 is_idle);
 } GpmScreensaverClass;
 
 GType		 gpm_screensaver_get_type		(void);
 GpmScreensaver	*gpm_screensaver_new			(void);
 
-int		 gpm_screensaver_get_delay		(GpmScreensaver	*screensaver);
 gboolean	 gpm_screensaver_lock			(GpmScreensaver	*screensaver);
 gboolean	 gpm_screensaver_lock_enabled		(GpmScreensaver	*screensaver);
 gboolean	 gpm_screensaver_lock_set		(GpmScreensaver	*screensaver,
 							 gboolean	 lock);
-gboolean	 gpm_screensaver_lock_enabled		(GpmScreensaver	*screensaver);
 guint32 	 gpm_screensaver_add_throttle    	(GpmScreensaver	*screensaver,
 							 const gchar	*reason);
 gboolean 	 gpm_screensaver_remove_throttle    	(GpmScreensaver	*screensaver,
 							 guint32         cookie);
 gboolean	 gpm_screensaver_check_running		(GpmScreensaver	*screensaver);
 gboolean	 gpm_screensaver_poke			(GpmScreensaver	*screensaver);
-gboolean	 gpm_screensaver_get_idle		(GpmScreensaver	*screensaver,
-							 gint		*time);
 
 G_END_DECLS
 
